@@ -116,7 +116,15 @@ pub fn deserialize_stellar_object(serialized_object: &Vec<u8>) -> Result<Stellar
 
 }
 
-pub fn serialize_stellar_objects(objects: &Vec<StellarObject>) -> Vec<u8> {
+pub fn serialize_stellar_objects(mut objects: Vec<StellarObject>) -> Vec<u8> {
+
+    objects.sort_by_key(|x| x.0.to_string());
+
+    objects.reverse();
+
+    objects.dedup_by_key(|x| x.0.to_string());
+
+    objects.sort_by_key(|x| x.0.to_string());
 
     let serialized_objects: Vec<Vec<u8>> = objects.iter()
         .map(|x| serialize_stellar_object(x))
